//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A3:WSSTR Can not create class: %s.\nPlease check the import library is right.","NX %s ł܂B\nǉR|[lg̐ݒ肪mFĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B3:WSSTR The name %s is already used by another instance.","IuWFNg %s ̂̂Ɩ̂dȂĂ܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C3:WSSTR Normal:0:,Invisible:4:,Deleted:1:,Default changed:2:,Hidden:3:","ʏ`:0:,s`:4:,폜:1:,lύX:2:,sύX:3:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D3:WSSTR Target class:","o^ΏۃNX:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E3:WSSTR Property name:","vpeB:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F3:WSSTR Property type:","vpeB^:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G3:WSSTR Variable name:","ϐ:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H3:WSSTR Default value:","ftHgl:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I3:WSSTR Attribute:","`:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J3:WSSTR Builder title:","r_^Cg:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K3:WSSTR Select menu:","lIꗗ:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L3:WSSTR Warning","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M3:WSSTR Invalid property name.\nPlease specify another name like WSNxxxx...","WSN Ŏn܂鐳vpeB\nw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR Invalid variable name...","ϐw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O3:WSSTR This name is already used by another procedure...","w肳ꂽ̂vV[W֐\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR This name is already used by another external instance.","w肳ꂽ̂̊O錾IuWFNĝ\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q3:WSSTR This name is already used by another external instance array.","w肳ꂽ̂̊O錾IuWFNgz񖼏̂\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R3:WSSTR This property name is already used by another property.","vpeBdĂ܂B\nقȂ閼̂ɂĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S3:WSSTR The variable is already used.","ϐdĂ܂B\nقȂ̂w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T3:WSSTR Create","쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U3:WSSTR Please specify the target class window.","ΏۃNXEBhEw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V3:WSSTR Please select the property.","vpeBIĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Question","mF");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X3:WSSTR Is it OK to delete the property?","vpeB폜Ă낵łH");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y3:WSSTR Update","ݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z3:WSSTR Create new property","vpeBVK쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a3:WSSTR Edit property","vpeBύX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b3:WSSTR Delete property","vpeB폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Type,Property name,Member name,Attribute,Default value","^,vpeB,o,,ftHgl");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:","VK쐬:NEW:,ҏW:EDIT:,폜:DEL:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","e3:WSSTR  Use the handler defined by user","[Uɂnh֐̒`");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f3:WSSTR (Normal)","(ʏ)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","g3:WSSTR (Deleted)","(폜)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","h3:WSSTR (DefaultChanged)","(lύX)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","i3:WSSTR (Hidden)","(sύX)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j3:WSSTR (Invisible)","(s)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k3:WSSTR Normal Def.:0:,Delete Def.:1:","ʏ`:0:,gK̍폜:1:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Target class:","o^ΏۃNX:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","m3:WSSTR Trigger name:","gK:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","n3:WSSTR Define name:","ft@C:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Define value:","ft@Cl:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Define type:","`:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","q3:WSSTR Invalid trigger name.","Xy[X܂܂ȂgK\nw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","r3:WSSTR Invalid define string...","ft@Cw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","s3:WSSTR Please specify the define value > 31.","32 ȏ̒lw肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","t3:WSSTR This trigger name is already used by another one.","gKdĂ܂B\nقȂ閼̂ɂĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","u3:WSSTR The define string is already used.","ft@C񂪏dĂ܂B\nقȂ̂w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","v3:WSSTR The value is already used.","w肵ldĂ܂B\nقȂ̂w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","w3:WSSTR Please select the trigger.","gKIĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","x3:WSSTR Is it OK to delete the trigger?","gK폜Ă낵łH");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","y3:WSSTR Create new trigger","gKVK쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","z3:WSSTR Edit trigger","gKύX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A3:WSSTR Delete trigger","gK폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B3:WSSTR Trigger Name,Trigger def,Trigger value,Attribute","gK,ft@C,ft@Cl,`");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C3:WSSTR New:NEW:,Edit:EDIT:,Delete:DEL:","VK쐬:NEW:,ҏW:EDIT:,폜:DEL:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D3:WSSTR All:",":");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E3:WSSTR R:",":");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F3:WSSTR G:",":");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G3:WSSTR B:",":");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H3:WSSTR Color:","IF:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I3:WSSTR Name:","F:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J3:WSSTR Add user color","[U`F̒ǉ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K3:WSSTR Edit user color","[U`F̕ҏW");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L3:WSSTR Delete user color","[U`F̍폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M3:WSSTR Default colors,Standard colors,User defined colors","ftHgF,X^_[hF,[U`F");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR Please select the user color.","ҏW[U`FIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O3:WSSTR Delete the selected color: ","IꂽF: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR  ?"," 폜܂?");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q3:WSSTR Please select the user color to delete.","폜[U`FIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R3:WSSTR %s:DISP:,Save:SAVE:,Search:SEARCH:,SP,Compile:COMP:,%s:PRJ:,SP,Copy:COPY:,Paste:PASTE:,SP,Delete:DEL:","%s:DISP:,ۑ:SAVE:,:SEARCH:,SP,RpC:COMP:,%s:PRJ:,SP,:COPY:,\x93\\t:PASTE:,SP,폜:DEL:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S3:WSSTR Files,Instances,Properties,Procedures,Attributes","t@C,CX^X,vpeB,vV[W,{ݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T3:WSSTR Name,Class",",NX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U3:WSSTR None:NONE:","Ȃ:NONE:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V3:WSSTR Display","\x95\\");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Add to project","vWFNg֓o^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X3:WSSTR Dismiss","\x95\\");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y3:WSSTR Remove from project","vWFNg֓o^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z3:WSSTR Add procedure","vV[W̒ǉ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a3:WSSTR Properties","vV[W̐ݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b3:WSSTR Edit procedure","vV[W̕ҏW");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Delete procedure","vV[W̍폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d3:WSSTR Instance:","o^ΏۃIuWFNg:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","e3:WSSTR Procedure name:","vV[W:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f3:WSSTR Trigger:","NgK:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","g3:WSSTR Function name:","N֐:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","h3:WSSTR Invalid procedure name...","vV[Ww肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","i3:WSSTR Invalid function name...","֐w肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j3:WSSTR Invalid procedure name...","vV[Ww肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k3:WSSTR Invalid procedure name.\nAlready used by another procedure name.","w肳ꂽ̂vV[W֐\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Invalid procedure name.\nAlready used by another instance name.","w肳ꂽ̂̊O錾IuWFNĝ\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","m3:WSSTR Invalid procedure name.\nAlready used by another instance array name.","w肳ꂽ̂̊O錾IuWFNgz񖼏̂\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","n3:WSSTR Invalid function name.","p݂̂̐֐w肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Create %s.cpp...","%s.cpp\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Create %s/%s.cpp...","%s/%s.cpp\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Create %s.rb...","%s.rb\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Create %s/%s.rb...","%s/%s.rb\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Create %s.py...","%s.py\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Create %s/%s.py...","%s/%s.py\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Create %s.pl...","%s.pl\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Create %s/%s.pl...","%s/%s.pl\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Create %s.java...","%s.java\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Create %s/%s.java...","%s/%s.java\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Create %s.ml...","%s.ml\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Create %s/%s.ml...","%s/%s.ml\n쐬܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","q3:WSSTR Overwrite existing file: %s?","%s\n݂܂Bu܂?");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","r3:WSSTR OK","쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","s3:WSSTR Please specify a target instance.","ΏۃIuWFNgw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","t3:WSSTR Please select a procedure.","vV[WIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","u3:WSSTR The procedure does not exist.","w肳ꂽvV[W݂͑܂ł.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","v3:WSSTR Delete this procedure?","vV[W폜Ă낵łH");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","w3:WSSTR Procedure name,Trigger,Function name","vV[W,gK,֐");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","x3:WSSTR File...","t@CI");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","y3:WSSTR Template","ЂȌ^쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","z3:WSSTR Internal","\x83\\[Xgp");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A3:WSSTR New:NEW:,Properties:SET:,Edit procedure:EDIT:,Delete procedure:DEL:","VK쐬:NEW:,vV[Wݒ:SET:,GfB^ҏW:EDIT:,폜:DEL:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B3:WSSTR done.\n","I܂.\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C3:WSSTR Break","~");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D3:WSSTR Defaults,Environments,Imports,Compiling,Linking,Fonts,Etc..","ftHgl,ݒ,ǉ,RpC,N,tHg,{ݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E3:WSSTR Default colors","ftHgFw");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F3:WSSTR Default size","ftHg傫w");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G3:WSSTR Grid size","Obhw");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H3:WSSTR :Horizontal",":w");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I3:WSSTR :Vertical",":x");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J3:WSSTR Base Window","EBhẼx[X");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K3:WSSTR Import Libraries","ǉR|[lg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L3:WSSTR Add","ǉ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M3:WSSTR Delete","폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR Terminal","^[~i");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O3:WSSTR Source editor","GfB^w");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O3:WSSTR Editor options","GfB^IvV");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Web browser","WebuEU");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q3:WSSTR Include path","ʃCN[hpX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R3:WSSTR Compiler flags","ʃRpCtO");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S3:WSSTR Compile mode","RpC@");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T3:WSSTR  Debug mode"," fobO[h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U3:WSSTR Application type","rh^Cv");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V3:WSSTR  Generate class library"," NXCuɂ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR C Compiler","C RpC");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR CPP Compiler","CPP RpC");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","ʏ탂[h,fobO[h,ʏX^eBbN[h,fobOX^eBbN[h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y3:WSSTR Include path","ʃCN[hpX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z3:WSSTR Compiler flags","ʃRpCtO");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a3:WSSTR Include path","fobOpCN[hpX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b3:WSSTR Compiler flags","fobOpRpCtO");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Libraries","ʃCuw");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d3:WSSTR Linker flags","ʃJtO");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","e3:WSSTR Linker","J");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f3:WSSTR Debugger","fobK");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f3:WSSTR Make","CNR}h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","g3:WSSTR Runtime mode,Debug mode","ʏ탂[h,fobO[h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","h3:WSSTR Libraries","ʃCu");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","i3:WSSTR Output file","o̓t@C");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j3:WSSTR Libraries","fobOpCu");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k3:WSSTR Output file","fobOpo̓t@C");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Please select a target to delete.","폜ΏۂIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","m3:WSSTR No-name","-s");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","n3:WSSTR Name:WSN%s  Type:%s",":WSN%s  ^:%s");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o3:WSSTR Invalid instance name.\nAlready used by another function name...","w肳ꂽ̂vV[W֐\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p3:WSSTR Invalid instance name.\nAlready used by another instance name...","w肳ꂽ̂̃IuWFNĝ\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","q3:WSSTR Invalid instance name.\nAlready used by another instance array name...","w肳ꂽ̂̔z񖼏̂ƏdȂĂ܂̂\nύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","r3:WSSTR Invalid instance name.\nAlready used by project name or something...","w肳ꂽ̂vWFNgȂǂ̖̂\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","s3:WSSTR Can not use array name for application window.","AvP[VEBhEɑ΂Ĕz񖼏͎̂g܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","t3:WSSTR Can not use array name for class window.","NXEBhEł͔z͎g܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","u3:WSSTR Invalid instance name.\nAlready used by another procedure name...","w肳ꂽ̂vV[W֐\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","v3:WSSTR Invalid instance name.\nAlready used by another external instance name...","w肳ꂽ̂̊O錾IuWFNĝ\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","w3:WSSTR Invalid instance array name.\nAlready used by another window, or invalid type.","w肳ꂽ̂̃EBhE̔z񖼏̂ƏdȂĂ邩\n܂́A^vĂȂ̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","x3:WSSTR Invalid instance name.\nAlready used by project name or something...","w肳ꂽ̂vWFNgȂǂ̖̂\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","y3:WSSTR Invalid instance name.","IuWFNĝw肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","z3:WSSTR This trigger already exists.","w肳ꂽgK݂͑܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A3:WSSTR This trigger already exists.","w肳ꂽgK݂͑܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B3:WSSTR Can not delete the fixed trigger.","w肵gK͍폜ł܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C3:WSSTR Please select a trigger to delete.","폜gKw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D3:WSSTR BaseClass","h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E3:WSSTR Base","x[X");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F3:WSSTR If you change window definition type,\nyou have to change the type of the event procedure.\nDo you continue?","^CvύX\nCxgvV[W̌^`قȂ܂̂ŁA\nRpCʂȂȂꍇ܂܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G3:WSSTR If it makes the class definition window type into another type,\nit needs to change the type of the event procedure.\nDo you continue?","NX`̃EBhEقȂ^CvɕύX\nCxgvV[W̌^`قȂ܂̂ŁA\nRpCʂȂȂꍇ܂܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H3:WSSTR inherit base instance: %s Not Found.\nPlease specify the correct instance name.","hɎw肵CX^X: %s \n݂͑܂BCX^Xw肵Ă.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I3:WSSTR Invalid name.\nAlready used by another event procedure.","w肳ꂽ̂vV[W֐\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J3:WSSTR Invalid name.\nAlready used by another instance name.","w肳ꂽ̂̃IuWFNĝ\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K3:WSSTR Invalid name.\nAlready used by another instance array name.","w肳ꂽ̂̔z񖼏̂ƏdȂĂ܂̂\nύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L3:WSSTR Invalid name.\nAlready used by the project name or the other one.","w肳ꂽ̂vWFNgȂǂ̖̑̂\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M3:WSSTR Can not specify the array name for window.","EBhEɑ΂Ĕz񖼏͎̂g܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR Can not specify the array name for class definition window.","NXEBhEł͔z͎g܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O3:WSSTR Invalid name.\nAlready used by another event procedure.","w肳ꂽ̂vV[W֐\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Invalid name.\nAlready used by another external instance.","w肳ꂽ̂̊O錾IuWFNĝ\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q3:WSSTR Invalid array name.\nThe Array type differs from another one,or exists also another window.","w肳ꂽ̂EBhE̔z񖼏̂ƏdȂĂ邩\n܂́A^vĂȂ̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R3:WSSTR Invalid name.\nAlready used by the project name or the other one.","w肳ꂽ̂vWFNgȂǂ̖̑̂\ndȂĂ܂̂ŕύXĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S3:WSSTR Invalid instance name.","IuWFNĝw肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T3:WSSTR ClassName","NX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U3:WSSTR Normal window","ʏEBhE");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V3:WSSTR Class definition","NXEBhE");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Use object store","XgA@\x94\\𗘗p");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X3:WSSTR Type","^Cv");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y3:WSSTR Settings","NXݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z3:WSSTR Properties","vpeBҏW");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a3:WSSTR Triggers","gKҏW");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b3:WSSTR UserTriggers","[UgKҏW");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Icon","ACR");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d3:WSSTR Comment","Rg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","e3:WSSTR Base","h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f3:WSSTR Name","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","g3:WSSTR File name","t@C");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","h3:WSSTR Access","錾");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","i3:WSSTR Global variable","O[o");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j3:WSSTR Project","o^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k3:WSSTR Belong to this project","vWFNg֓o^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Member","o");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR ENCODING","R[ȟn");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR COMPAT","TARGET");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Platform compatible","vbgtH[݊");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Look & Feel","Look & Feel");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Gradation","Gradation");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Gui Policy","fth|V[");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR PropertyEditor","vpeBGfB^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR PropertyName:","vpeB:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR PropertyType:","vpeB^:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR PropertyValue:","vpeBl:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N3:WSSTR broken.","𒆒f܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR OBJS","ǉIuWFNg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F3:WSSTR If you change class window name,\nyou have to reject your old source code\nand change the name of the event procedure.\nDo you continue?","NXύXƁA܂łɍ쐬\x83\\[XR[h\nCxgvV[W̒`ύXȂĂ͂Ȃ܂B\n܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR ColorBox","Fݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR MessageBox","bZ[W{bNX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j3:WSSTR RemoteClass","[g@\x94\\");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k3:WSSTR Generates the virtual remote class","z[gNX𐶐");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b3:WSSTR RemoteMethods","[g\x83\\bh");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Return type,Method name","Ԓl^,\x83\\bh");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G3:WSSTR Parameters","p[^ݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Type,Name","^,");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Add","ǉ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Del","폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Up","ֈړ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Down","ֈړ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E3:WSSTR Method name:","\x83\\bh");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F3:WSSTR Return value type:","Ԓl^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H3:WSSTR Name/Type","/^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R3:WSSTR The method name is already used.","w肳ꂽ\x83\\bĥ͊ɎgpĂ܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S3:WSSTR Invalid method name.","sȃ\x83\\bĥłB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V3:WSSTR Please select the method.","\x83\\bhIĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d3:WSSTR RemoteClassName:","z[gNX:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d3:WSSTR BaseClassName:","hz[gNX:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K3:WSSTR Edit...","ݒ...");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Name of the struct:","\x8d\\̖");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Name of the value:","l");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W3:WSSTR Value:","l");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c3:WSSTR Name,Value",",l");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Ruby","Ruby");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Ruby(DBG)","Ruby(DBG)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Python","Python");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Python(DBG)","Python(DBG)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Perl","Perl");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Perl(DBG)","Perl(DBG)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Java","Java");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P3:WSSTR Java(make)","Java(make)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f3:WSSTR Static option","N");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Statically linked","X^eBbNN(DLL )");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l3:WSSTR Dynamically linked","_Ci~bNN(DLL )");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K3:WSSTR Import source files","ǉ\x83\\[XR[h");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A3:WSSTR Copy    :COPY:,Paste:PASTE:,SP,Properties:PROP:,Procedures:OP:,Attributes:EXPROP:,SP,Delete:DEL:","    :COPY:,\x93\\t:PASTE:,SP,vpeB:PROP:,vV[W:OP:,eݒ:EXPROP:,SP,폜:DEL:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A3:WSSTR Copy    :COPY:,Paste:PASTE:,SP,Properties:PROP:,Procedures:OP:,Attributes:EXPROP:,SP,Front:FRONT:,Back:BACK:,SP,Delete:DEL:","    :COPY:,\x93\\t:PASTE:,SP,vpeB:PROP:,vV[W:OP:,eݒ:EXPROP:,SP,Oʂ:FRONT:,wʂ:BACK:,SP,폜:DEL:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A:WSSTR  //please edit here...\n","  //Lqĉ\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B:WSSTR\n\n//Initializing of class...\n","\n\n//NX\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C:WSSTR//##### IMPORTANT: Do not edit from here  #######\n\n","//##### IMPORTANT  ȉAҏWĂ͂Ȃ܂  #######\n\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D:WSSTR//##### IMPORTANT: Do not edit to here  #######\n\n","//##### IMPORTANT  ܂ł͕ҏWĂ͂Ȃ܂     #########\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E:WSSTR();\n\n    // class definitions/////////////////////////////////\n","();\n\n    //hEp錾 ////////////////////////////////////\n");
